Class: Aws::TrustedAdvisor::Types::GetRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::TrustedAdvisor::Types::GetRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-trustedadvisor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#language ⇒ String
The ISO 639-1 code for the language that you want your recommendations to appear in.
-
#recommendation_identifier ⇒ String
The Recommendation identifier.
Instance Attribute Details
#language ⇒ String
The ISO 639-1 code for the language that you want your recommendations to appear in.
206 207 208 209 210 211 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 206 class GetRecommendationRequest < Struct.new( :recommendation_identifier, :language) SENSITIVE = [] include Aws::Structure end |
#recommendation_identifier ⇒ String
The Recommendation identifier
206 207 208 209 210 211 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 206 class GetRecommendationRequest < Struct.new( :recommendation_identifier, :language) SENSITIVE = [] include Aws::Structure end |