Class: Aws::TrustedAdvisor::Types::OrganizationRecommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::TrustedAdvisor::Types::OrganizationRecommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-trustedadvisor/types.rb
Overview
A Recommendation for accounts within an Organization
Constant Summary collapse
- SENSITIVE =
[:update_reason]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Recommendation.
-
#aws_services ⇒ Array<String>
The AWS Services that the Recommendation applies to.
-
#check_arn ⇒ String
The AWS Trusted Advisor Check ARN that relates to the Recommendation.
-
#created_at ⇒ Time
When the Recommendation was created, if created by AWS Trusted Advisor Priority.
-
#created_by ⇒ String
The creator, if created by AWS Trusted Advisor Priority.
-
#description ⇒ String
A description for AWS Trusted Advisor recommendations.
-
#id ⇒ String
The ID which identifies where the Recommendation was produced.
-
#last_updated_at ⇒ Time
When the Recommendation was last updated.
-
#lifecycle_stage ⇒ String
The lifecycle stage from AWS Trusted Advisor Priority.
-
#name ⇒ String
The name of the AWS Trusted Advisor Recommendation.
-
#pillar_specific_aggregates ⇒ Types::RecommendationPillarSpecificAggregates
The pillar aggregations for cost savings.
-
#pillars ⇒ Array<String>
The Pillars that the Recommendation is optimizing.
-
#resolved_at ⇒ Time
When the Recommendation was resolved.
-
#resources_aggregates ⇒ Types::RecommendationResourcesAggregates
An aggregation of all resources.
-
#source ⇒ String
The source of the Recommendation.
-
#status ⇒ String
The status of the Recommendation.
-
#type ⇒ String
Whether the Recommendation was automated or generated by AWS Trusted Advisor Priority.
-
#update_reason ⇒ String
Reason for the lifecycle stage change.
-
#update_reason_code ⇒ String
Reason code for the lifecycle state change.
-
#updated_on_behalf_of ⇒ String
The person on whose behalf a Technical Account Manager (TAM) updated the recommendation.
-
#updated_on_behalf_of_job_title ⇒ String
The job title of the person on whose behalf a Technical Account Manager (TAM) updated the recommendation.
Instance Attribute Details
#arn ⇒ String
The ARN of the Recommendation
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#aws_services ⇒ Array<String>
The AWS Services that the Recommendation applies to
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#check_arn ⇒ String
The AWS Trusted Advisor Check ARN that relates to the Recommendation
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#created_at ⇒ Time
When the Recommendation was created, if created by AWS Trusted Advisor Priority
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#created_by ⇒ String
The creator, if created by AWS Trusted Advisor Priority
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#description ⇒ String
A description for AWS Trusted Advisor recommendations
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#id ⇒ String
The ID which identifies where the Recommendation was produced
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#last_updated_at ⇒ Time
When the Recommendation was last updated
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#lifecycle_stage ⇒ String
The lifecycle stage from AWS Trusted Advisor Priority
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#name ⇒ String
The name of the AWS Trusted Advisor Recommendation
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#pillar_specific_aggregates ⇒ Types::RecommendationPillarSpecificAggregates
The pillar aggregations for cost savings
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#pillars ⇒ Array<String>
The Pillars that the Recommendation is optimizing
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#resolved_at ⇒ Time
When the Recommendation was resolved
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#resources_aggregates ⇒ Types::RecommendationResourcesAggregates
An aggregation of all resources
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#source ⇒ String
The source of the Recommendation
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#status ⇒ String
The status of the Recommendation
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#type ⇒ String
Whether the Recommendation was automated or generated by AWS Trusted Advisor Priority
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#update_reason ⇒ String
Reason for the lifecycle stage change
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#update_reason_code ⇒ String
Reason code for the lifecycle state change
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#updated_on_behalf_of ⇒ String
The person on whose behalf a Technical Account Manager (TAM) updated the recommendation. This information is only available when a Technical Account Manager takes an action on a recommendation managed by AWS Trusted Advisor Priority
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#updated_on_behalf_of_job_title ⇒ String
The job title of the person on whose behalf a Technical Account Manager (TAM) updated the recommendation. This information is only available when a Technical Account Manager takes an action on a recommendation managed by AWS Trusted Advisor Priority
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 732 class OrganizationRecommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |