Class: Aws::TrustedAdvisor::Types::Recommendation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-trustedadvisor/types.rb

Overview

A Recommendation for an Account

Constant Summary collapse

SENSITIVE =
[:update_reason]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the Recommendation

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#aws_servicesArray<String>

The AWS Services that the Recommendation applies to

Returns:

  • (Array<String>)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#check_arnString

The AWS Trusted Advisor Check ARN that relates to the Recommendation

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#created_atTime

When the Recommendation was created, if created by AWS Trusted Advisor Priority

Returns:

  • (Time)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#created_byString

The creator, if created by AWS Trusted Advisor Priority

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#descriptionString

A description for AWS Trusted Advisor recommendations

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#idString

The ID which identifies where the Recommendation was produced

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#last_updated_atTime

When the Recommendation was last updated

Returns:

  • (Time)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#lifecycle_stageString

The lifecycle stage from AWS Trusted Advisor Priority

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#nameString

The name of the AWS Trusted Advisor Recommendation

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#pillar_specific_aggregatesTypes::RecommendationPillarSpecificAggregates

The pillar aggregations for cost savings



1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#pillarsArray<String>

The Pillars that the Recommendation is optimizing

Returns:

  • (Array<String>)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#resolved_atTime

When the Recommendation was resolved

Returns:

  • (Time)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#resources_aggregatesTypes::RecommendationResourcesAggregates

An aggregation of all resources



1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#sourceString

The source of the Recommendation

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#statusString

The status of the Recommendation

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#status_reasonString

This attribute provides additional details about potential discrepancies in check status determination.

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#typeString

Whether the Recommendation was automated or generated by AWS Trusted Advisor Priority

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#update_reasonString

Reason for the lifecycle stage change

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#update_reason_codeString

Reason code for the lifecycle state change

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#updated_on_behalf_ofString

The person on whose behalf a Technical Account Manager (TAM) updated the recommendation. This information is only available when a Technical Account Manager takes an action on a recommendation managed by AWS Trusted Advisor Priority

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end

#updated_on_behalf_of_job_titleString

The job title of the person on whose behalf a Technical Account Manager (TAM) updated the recommendation. This information is only available when a Technical Account Manager takes an action on a recommendation managed by AWS Trusted Advisor Priority

Returns:

  • (String)


1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000

class Recommendation < Struct.new(
  :id,
  :type,
  :check_arn,
  :status,
  :lifecycle_stage,
  :pillars,
  :source,
  :aws_services,
  :name,
  :resources_aggregates,
  :pillar_specific_aggregates,
  :created_at,
  :last_updated_at,
  :arn,
  :status_reason,
  :description,
  :created_by,
  :updated_on_behalf_of,
  :updated_on_behalf_of_job_title,
  :update_reason,
  :update_reason_code,
  :resolved_at)
  SENSITIVE = [:update_reason]
  include Aws::Structure
end