Class: Aws::TrustedAdvisor::Types::RecommendationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::TrustedAdvisor::Types::RecommendationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-trustedadvisor/types.rb
Overview
Summary of Recommendation for an Account
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Recommendation.
-
#aws_services ⇒ Array<String>
The AWS Services that the Recommendation applies to.
-
#check_arn ⇒ String
The AWS Trusted Advisor Check ARN that relates to the Recommendation.
-
#created_at ⇒ Time
When the Recommendation was created, if created by AWS Trusted Advisor Priority.
-
#id ⇒ String
The ID which identifies where the Recommendation was produced.
-
#last_updated_at ⇒ Time
When the Recommendation was last updated.
-
#lifecycle_stage ⇒ String
The lifecycle stage from AWS Trusted Advisor Priority.
-
#name ⇒ String
The name of the AWS Trusted Advisor Recommendation.
-
#pillar_specific_aggregates ⇒ Types::RecommendationPillarSpecificAggregates
The pillar aggregations for cost savings.
-
#pillars ⇒ Array<String>
The Pillars that the Recommendation is optimizing.
-
#resources_aggregates ⇒ Types::RecommendationResourcesAggregates
An aggregation of all resources.
-
#source ⇒ String
The source of the Recommendation.
-
#status ⇒ String
The status of the Recommendation.
-
#status_reason ⇒ String
This attribute provides additional details about potential discrepancies in check status determination.
-
#type ⇒ String
Whether the Recommendation was automated or generated by AWS Trusted Advisor Priority.
Instance Attribute Details
#arn ⇒ String
The ARN of the Recommendation
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#aws_services ⇒ Array<String>
The AWS Services that the Recommendation applies to
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#check_arn ⇒ String
The AWS Trusted Advisor Check ARN that relates to the Recommendation
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
When the Recommendation was created, if created by AWS Trusted Advisor Priority
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID which identifies where the Recommendation was produced
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
When the Recommendation was last updated
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#lifecycle_stage ⇒ String
The lifecycle stage from AWS Trusted Advisor Priority
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the AWS Trusted Advisor Recommendation
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#pillar_specific_aggregates ⇒ Types::RecommendationPillarSpecificAggregates
The pillar aggregations for cost savings
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#pillars ⇒ Array<String>
The Pillars that the Recommendation is optimizing
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#resources_aggregates ⇒ Types::RecommendationResourcesAggregates
An aggregation of all resources
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the Recommendation
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Recommendation
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
This attribute provides additional details about potential discrepancies in check status determination.
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Whether the Recommendation was automated or generated by AWS Trusted Advisor Priority
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1236 class RecommendationSummary < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason) SENSITIVE = [] include Aws::Structure end |