Class: Aws::TrustedAdvisor::Types::Recommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::TrustedAdvisor::Types::Recommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-trustedadvisor/types.rb
Overview
A Recommendation for an Account
Constant Summary collapse
- SENSITIVE =
[:update_reason]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Recommendation.
-
#aws_services ⇒ Array<String>
The AWS Services that the Recommendation applies to.
-
#check_arn ⇒ String
The AWS Trusted Advisor Check ARN that relates to the Recommendation.
-
#created_at ⇒ Time
When the Recommendation was created, if created by AWS Trusted Advisor Priority.
-
#created_by ⇒ String
The creator, if created by AWS Trusted Advisor Priority.
-
#description ⇒ String
A description for AWS Trusted Advisor recommendations.
-
#id ⇒ String
The ID which identifies where the Recommendation was produced.
-
#last_updated_at ⇒ Time
When the Recommendation was last updated.
-
#lifecycle_stage ⇒ String
The lifecycle stage from AWS Trusted Advisor Priority.
-
#name ⇒ String
The name of the AWS Trusted Advisor Recommendation.
-
#pillar_specific_aggregates ⇒ Types::RecommendationPillarSpecificAggregates
The pillar aggregations for cost savings.
-
#pillars ⇒ Array<String>
The Pillars that the Recommendation is optimizing.
-
#resolved_at ⇒ Time
When the Recommendation was resolved.
-
#resources_aggregates ⇒ Types::RecommendationResourcesAggregates
An aggregation of all resources.
-
#source ⇒ String
The source of the Recommendation.
-
#status ⇒ String
The status of the Recommendation.
-
#status_reason ⇒ String
This attribute provides additional details about potential discrepancies in check status determination.
-
#type ⇒ String
Whether the Recommendation was automated or generated by AWS Trusted Advisor Priority.
-
#update_reason ⇒ String
Reason for the lifecycle stage change.
-
#update_reason_code ⇒ String
Reason code for the lifecycle state change.
-
#updated_on_behalf_of ⇒ String
The person on whose behalf a Technical Account Manager (TAM) updated the recommendation.
-
#updated_on_behalf_of_job_title ⇒ String
The job title of the person on whose behalf a Technical Account Manager (TAM) updated the recommendation.
Instance Attribute Details
#arn ⇒ String
The ARN of the Recommendation
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#aws_services ⇒ Array<String>
The AWS Services that the Recommendation applies to
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#check_arn ⇒ String
The AWS Trusted Advisor Check ARN that relates to the Recommendation
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#created_at ⇒ Time
When the Recommendation was created, if created by AWS Trusted Advisor Priority
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#created_by ⇒ String
The creator, if created by AWS Trusted Advisor Priority
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#description ⇒ String
A description for AWS Trusted Advisor recommendations
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#id ⇒ String
The ID which identifies where the Recommendation was produced
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#last_updated_at ⇒ Time
When the Recommendation was last updated
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#lifecycle_stage ⇒ String
The lifecycle stage from AWS Trusted Advisor Priority
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#name ⇒ String
The name of the AWS Trusted Advisor Recommendation
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#pillar_specific_aggregates ⇒ Types::RecommendationPillarSpecificAggregates
The pillar aggregations for cost savings
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#pillars ⇒ Array<String>
The Pillars that the Recommendation is optimizing
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#resolved_at ⇒ Time
When the Recommendation was resolved
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#resources_aggregates ⇒ Types::RecommendationResourcesAggregates
An aggregation of all resources
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#source ⇒ String
The source of the Recommendation
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#status ⇒ String
The status of the Recommendation
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#status_reason ⇒ String
This attribute provides additional details about potential discrepancies in check status determination.
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#type ⇒ String
Whether the Recommendation was automated or generated by AWS Trusted Advisor Priority
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#update_reason ⇒ String
Reason for the lifecycle stage change
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#update_reason_code ⇒ String
Reason code for the lifecycle state change
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#updated_on_behalf_of ⇒ String
The person on whose behalf a Technical Account Manager (TAM) updated the recommendation. This information is only available when a Technical Account Manager takes an action on a recommendation managed by AWS Trusted Advisor Priority
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |
#updated_on_behalf_of_job_title ⇒ String
The job title of the person on whose behalf a Technical Account Manager (TAM) updated the recommendation. This information is only available when a Technical Account Manager takes an action on a recommendation managed by AWS Trusted Advisor Priority
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/aws-sdk-trustedadvisor/types.rb', line 1000 class Recommendation < Struct.new( :id, :type, :check_arn, :status, :lifecycle_stage, :pillars, :source, :aws_services, :name, :resources_aggregates, :pillar_specific_aggregates, :created_at, :last_updated_at, :arn, :status_reason, :description, :created_by, :updated_on_behalf_of, :updated_on_behalf_of_job_title, :update_reason, :update_reason_code, :resolved_at) SENSITIVE = [:update_reason] include Aws::Structure end |